@@ -3,7 +3,7 @@ package CPAN::Patches;
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moose;
 use CPAN::Patches::SPc;
@@ -47,7 +47,7 @@ sub patch {
     foreach my $patch_filename ($self->get_patch_series) {
         print 'patching ', $name,' with ', $patch_filename, "\n"
             if $self->verbose;
-        system('cat '.$patch_filename.' | patch --quiet -p1') and die 'failed';
+        system('cat '.$patch_filename.' | patch --quiet --force -p1') and die 'failed';
     }
     
     return;
@@ -163,6 +163,8 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 CPAN::Patches - patch CPAN distributions
@@ -244,6 +246,15 @@ than tries to read from current folder.
 
 Generates and reads the F<META.yml> using F<Build.PL> or F<Makefile.PL>.
 
+=head1 CONTRIBUTORS
+
+The following people have contributed to the CPAN::Patches by committing their
+code, sending patches, reporting bugs, asking questions, suggesting useful
+advises, nitpicking, chatting on IRC or commenting on my blog (in no particular
+order):
+
+	Slaven Rezić
+
 =head1 AUTHOR
 
 jozef@kutej.net, C<< <jkutej at cpan.org> >>
