@@ -1,15 +1,9 @@
 package CPAN::Patches::SPc;
 
-=head1 NAME
-
-Acme::SysPath::SPc - build-time system path configuration
-
-=cut
-
 use warnings;
 use strict;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use File::Spec;
 
@@ -17,6 +11,18 @@ sub _path_types {qw(
 	sharedstatedir
 )};
 
+sub prefix     { use Sys::Path; Sys::Path->find_distribution_root(__PACKAGE__); };
+sub sharedstatedir { File::Spec->catdir(__PACKAGE__->prefix, 'sharedstate') };
+
+1;
+
+
+__END__
+
+=head1 NAME
+
+Acme::SysPath::SPc - build-time system path configuration
+
 =head1 PATHS
 
 =head2 prefix
@@ -26,17 +32,3 @@ sub _path_types {qw(
 Used to lookup for patches set.
 
 =cut
-
-sub prefix     { use Sys::Path; Sys::Path->find_distribution_root(__PACKAGE__); };
-sub sharedstatedir { File::Spec->catdir(__PACKAGE__->prefix, 'sharedstate') };
-
-1;
-
-
-__END__
-
-=head1 AUTHOR
-
-Jozef Kutej
-
-=cut
